@@ -57,6 +57,7 @@ def get_userinfo_from_external_id(external_id):
     # Call regapp
     BWIDM = BwIdmConnection(CONFIG)
     resp = BWIDM.get ('external-user', 'find', 'externalId', external_id)
+    print (F"RESP: {resp}")
     resp_json = safe_resp_conversion(resp)
 
     return resp_json
@@ -164,13 +165,13 @@ def deregister_external_id_from_service(external_id, service_name):
     resp_json = safe_resp_conversion(resp)
     return resp_json
 def deactivate_user(external_id):
-    '''deregister user from given service'''
+    '''deactivate user from given service'''
     # Call regapp
     BWIDM = BwIdmConnection(CONFIG)
     resp = BWIDM.get ('external-user', 'deactivate', 'externalId', external_id)
     return resp
 def activate_user(external_id):
-    '''deregister user from given service'''
+    '''activate user from given service'''
     # Call regapp
     BWIDM = BwIdmConnection(CONFIG)
     resp = BWIDM.get ('external-user', 'activate', 'externalId', external_id)
@@ -183,9 +184,16 @@ def register_external_id_from_service(external_id, service_name):
     resp_json = safe_resp_conversion(resp)
     return resp_json
 def get_list_of_all_users():
-    '''register user from given service'''
+    '''Get list of all users'''
     # Call regapp
     BWIDM = BwIdmConnection(CONFIG)
     resp = BWIDM.get ('external-user', 'find', 'all')
     resp_json = safe_resp_conversion(resp)
     return resp_json
+def get_list_of_registrations_in_service(service):
+    '''Get list of all users from given service'''
+    # Call regapp
+    BWIDM = BwIdmConnection(CONFIG)
+    resp = BWIDM.get ('external-reg', 'find', 'all', 'ssn', service)
+    resp_json = safe_resp_conversion(resp)
+    return resp_json
