@@ -24,10 +24,11 @@ def load_config():
     Config locations, by priority (first one wins)
     """
     files = []
-    try:
+    if args.config is not None:
+        if not Path(args.config).exists():
+            logger.error(F"Cannot file specified config file: {args.config}")
+            s_exit(3)
         files += [ Path(args.config) ]
-    except FileNotFoundError:
-        pass
 
     logger.info("reading config")
 
